<template>
    <div class="row" v-if="products.length > 0">
        <div class="col-sm-12 col-md-12 col-lg-12" :key="componentKey">
            <div class="related-products">
                <h3>Related Products</h3>
                <div class="product_listing">
                    <div>
                        <div class="price_filter mb-0"></div>
                        <div class="row">
                            <div class="col-12 col-sm-6 col-md-4 col-lg-4 col-xl-3" v-for="(product, i) in products" :key="i">
                                <div class="product_item"><a :href="buildProductUrl(product)">
                                        <div class="product_flag"></div>
                                        <div class="product_img"><img v-if="product.file_upload.length > 0"
                                            :src="`${options.storage_root}/` + product.file_upload[0].upload.uploaded_path"
                                            :title="(product.file_upload[0].title != null) ? product.file_upload[0].title : product.name"
                                            :alt="(product.file_upload[0].alt_text != null) ? product.file_upload[0].alt_text : product.name">
                                        <img :alt="product.name" v-else src="/images/no-img.png">
                                        </div>
                                        <div class="product_info">
                                            <h4>{{ product.default_category.name }}</h4>
                                            <h2>{{ product.name }}</h2>
                                            <div class="pricings">
                                                <ul v-if="Object.values(product.pricings).length > 0">
                                                    <li ><span>From</span> ${{(Object.values(product.pricings)[0].price*1).toFixed(2)}}/wk </li>
                                                </ul>
                                            </div>
                                            <div class="view_btn_price">View Pricing</div>
                                        </div>
                                    </a></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>


    
</template>
<script>
import { cloneDeep } from 'lodash';
import options from '~/assets/options';
export default {
    props: ['products'],
    data() {
        return {
            options: options,
            componentKey: 1,
            location_name: "",
            domain: this.$store.state.front_end_data.domain,
        }
    },
    mounted() {
        this.location_name = this.$store.state.front_end_data.location_name;
        this.$store.watch(() => this.$store.state.front_end_data, async () => {
            this.location_name = this.$store.state.front_end_data.location_name;
        });
    },
    methods: {
        buildProductUrl(product) {
            let parent_category = (product.default_category.parent_category != null) ? product.default_category.parent_category.link_rewrite + '/' : "";
            let route = '/' + this.location_name + '/' + parent_category + product.default_category.link_rewrite + '/' + product.link_rewrite;
            return route;
        },
        viewDetail(product) {
            if (!this.$store.state.ssr_mode) {
                window.open('/' + this.location_name + '/' + product.default_category.link_rewrite + '/' + product.link_rewrite, '_self');
            }
        },
        getPrice(product) {
            let price_list = [];
            for (var i in product.pricings) {
                price_list.push(product.pricings[i]);
            }
            let pricings = price_list.map(x => ({ ...x, name: `${(x.rent_term != null) ? x.rent_term.name : x.custom_rent_term} ${(x.rent_period != null) ? x.rent_period.name : ""}` }));
            return pricings;
        },
    }
}
</script>